@@ -201,6 +201,18 @@ LOGIN_SETTINGS_FIELDS = [
             ``rest_registration.token_managers.AbstractTokenManager``.
             """)
     ),
+    Field(
+        'LOGIN_DEFAULT_SESSION_AUTHENTICATION_BACKEND',
+        default='django.contrib.auth.backends.ModelBackend',
+        help=dedent("""\
+            This setting allows to override the backend used in the login function.
+
+            It may be useful if Django ``AUTHENTICATION_BACKENDS`` setting
+            does contain multiple values.
+
+            The value must be a dotted import path string.
+            """),
+    )
 ]
 RESET_PASSWORD_SETTINGS_FIELDS = [
     Field(
@@ -374,6 +386,31 @@ GLOBAL_VERIFICATION_SETTINGS_FIELDS = [
             of the function.
             """),
     ),
+    Field(
+        'VERIFICATION_TEMPLATE_RENDERER',
+        default='rest_registration.utils.verification.default_render_template',
+        import_string=True,
+        help=dedent("""\
+            The builder function receives these parameters as
+            positional arguments:
+
+            *   ``template_config_data`` - dictionary; data is populated by
+                function set with :ref:`verification-templates-selector-setting`
+                setting.
+            *   ``context`` - dictionary; data is populated by function set
+                with :ref:`verification-template-context-builder-setting`
+                setting.
+
+            Function should return an instance of
+            ``rest_registration.utils.verification.EmailTemplateRenderResult``
+
+            It is possible that in the future, additional keyword arguments
+            may be added. Therefore the implementer
+            of the custom builder function should take account of that,
+            for instance by adding ``**kwargs`` in the signature
+            of the function.
+        """),
+    ),
     Field(
         'VERIFICATION_TEMPLATES_SELECTOR',
         default='rest_registration.utils.verification.select_default_templates',
